@@ -4,7 +4,7 @@ AtteanX::Serializer::Turtle - Turtle Serializer
 
 =head1 VERSION
 
-This document describes AtteanX::Serializer::Turtle version 0.011
+This document describes AtteanX::Serializer::Turtle version 0.015
 
 =head1 SYNOPSIS
 
@@ -39,7 +39,7 @@ This document describes AtteanX::Serializer::Turtle version 0.011
 use v5.14;
 use warnings;
 
-package AtteanX::Serializer::Turtle 0.011 {
+package AtteanX::Serializer::Turtle 0.015 {
 	use Moo;
 	use Data::Dumper;
 	use Encode qw(encode);
@@ -103,7 +103,7 @@ L<IO::Handle> object C<< $fh >>.
 		my $semi	= AtteanX::Parser::Turtle::Token->semicolon;
 		if (my $map = $self->namespaces) {
 			my $prefix	= AtteanX::Parser::Turtle::Token->prefix;
-			foreach my $ns ($map->list_prefixes) {
+			foreach my $ns (sort $map->list_prefixes) {
 				my $uri		= Attean::IRI->new( value => $map->namespace_uri($ns)->as_string );
 				my $name	= AtteanX::Parser::Turtle::Token->fast_constructor( PREFIXNAME, -1, -1, -1, -1, ["${ns}:"] );
 				my $iri		= AtteanX::Parser::Turtle::Token->fast_constructor( IRI, -1, -1, -1, -1, [$uri->value] );
